% Franck Portier, May 2020
% Here I estimate a simple one equation forward looking non linear model
% Model is :
% x(t) = alphap1 E[x(t+1)] + alpham1 x(t-1) + alphax3 x(t)^3 + epsx
% Data come from Oder3Simulate.mod


var x ;
varexo epsx;
 
parameters alphaxp1 alphaxm1 alphax3;

alphaxp1    =   .3;
alphaxm1    =   .6;
alphax3     =   -.2;




model;
x = alphaxp1*x(+1) + alphaxm1*x(-1) + alphax3*x^3 + epsx;
end;
 
steady;
check;

shocks;
var epsx = 1;
end;

varobs x;

%% Let's estimate only the linear part of the model. 
% It works (I mean it computes something)

estimated_params;
alphaxp1,.2;
alphaxm1,.5;
% alphax3, -.1;
end;

estimation(datafile=DataOrder3,mode_compute=7,order=1);


%% Now let's try to estimate the non-linear model

estimated_params;
alphaxp1,.2;
alphaxm1,.5;
alphax3, -.1;
end;


% The following two lines are suggested by the error message, but are not
% solving the problem

estimated_params_init(use_calibration);
end;
 
  
 
estimation(datafile=DataOrder3,mode_compute=7,order=3);

 